#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mmark
version:              0.0.8.0
visibility:           public
id:                   mmark-0.0.8.0-B3RZvtKYfT7AOOoEhwf4Qj
key:                  mmark-0.0.8.0-B3RZvtKYfT7AOOoEhwf4Qj
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mmark-md/mmark
synopsis:             Strict markdown processor for writers
description:          Strict markdown processor for writers.
category:             Text
abi:                  fa28cb82fa6cac01bd9df15682157bc6
exposed:              True
exposed-modules:
    Text.MMark Text.MMark.Extension Text.MMark.Internal.Type
    Text.MMark.Render Text.MMark.Trans Text.MMark.Util

hidden-modules:
    Text.MMark.Parser Text.MMark.Parser.Internal
    Text.MMark.Parser.Internal.Type

import-dirs:          /usr/lib/ghc-9.6.6/site-local/mmark-0.0.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mmark-0.0.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mmark-0.0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmark
hs-libraries:         HSmmark-0.0.8.0-B3RZvtKYfT7AOOoEhwf4Qj
depends:
    aeson-2.2.2.0-4XfhhWkmpwnB2gRUwfJP7g base-4.18.2.1
    case-insensitive-1.2.1.0-JWd1XK3KOo7EjUmuZpwp5W containers-0.6.7
    deepseq-1.4.8.1 dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp
    email-validate-2.3.2.21-4s2XU1ISRuJ2pliHqQEYt2
    foldl-1.4.18-EGH18BpMSCl5Gn5RMl1xlz
    hashable-1.4.7.0-DjTaTzSxyhZLemTcoX34jw
    html-entity-map-0.1.0.0-ECSJkbTDnGqLUP0lKlbzSq
    lucid-2.11.20260427-BJys5UhCas3KJDdDdlhOie
    megaparsec-9.7.1-IJJCy7AfSWn4uupFAyXCnh
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT
    modern-uri-0.3.6.1-CMqKCqY9qQVG1BmabWHJtd mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m text-2.0.2
    text-metrics-0.3.3-GMnvyHxgcHDErZUEWUIgk8
    unordered-containers-0.2.20.1-3DXXOqLpcMZGFktSBwG2cs
    yaml-0.11.11.2-58WeWnkZTUG9e3PdNR129q

haddock-interfaces:   /usr/share/doc/haskell-mmark/html/mmark.haddock
haddock-html:         /usr/share/doc/haskell-mmark/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

